==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Probíhá zaznamenávání videa. Zavřít okno?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otevřít složku</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otevřít složku</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nemáte oprávnění operovat v této složce</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>Neplatná složka</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otevřít složku</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Základní</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Umístění souboru</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Snímek</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Dávkový režim</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Prodleva samospouště</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Výstupní formát</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 ks</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 ks</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera je nástroj pro zachytávání obrazu a videa pomocí kamery počítače.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Soubor neuložen</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Uložit do:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotka:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Nastavení rozlišení</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Rozlišení:</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Pořídit fotku</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Zaznamenat video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Přestat pořizovat fotky</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenalezena žádná webová kamera</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Webová kamera je používána</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Zastavit zaznamenávání</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.1.2.orig.tar.xz: deepin-camera-1.1.2/src/translations/deepin-camera_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Probíhá zaznamenávání videa. Zavřít okno?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otevřít složku</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otevřít složku</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Vytisknout</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nemáte oprávnění operovat v této složce</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Neplatná složka</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otevřít složku</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Základní</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Umístění souboru</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Snímek</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Dávkový režim</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Prodleva samospouště</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Výstupní formát</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 ks</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 ks</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera je nástroj pro zachytávání obrazu a videa pomocí kamery počítače.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Soubor neuložen</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Uložit do:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotka:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Nastavení rozlišení</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Rozlišení:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotky:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videa:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Zvukové efekty</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Zastavit zaznamenávání</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Vytisknout</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Přestat pořizovat fotky</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontextová nabídka</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Pořídit fotku</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Zaznamenat video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Přestat pořizovat fotky</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenalezena žádná webová kamera</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Webová kamera je používána</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Zastavit zaznamenávání</translation>
    </message>
</context>
</TS>
